# silico

Python package to handle in silico experiments


## Installation
Assuming you have a [Python3](https://www.python.org/) distribution with [pip](https://pip.pypa.io/en/stable/installing/):

```bash
pip3 install silico
```

## Command line interface
To run the command line interface see:
```bash
silico --help
```

If the bin is not in the path you can do instead:
```bash
python -m silico --help
```
